#!/opt/SPECTRUM/bin/perl -w

# This script will capture the startup configuration and print it to STDOUT.
#

use strict;
use warnings;

my @data;
my $errorCode;
our $deviceIP;

my $expscript='/path/to/NCM_sshRunConfig.exp';


# Use these for Additional Script Parameters
# SSH Login Timeout: 5
# SSH Config Caputure Timeout: 10

# Use these as the Error Code Mappings
# Error Codes:
#   0   = Success
#   255 = Usage error
#   254 = Invalid timeout value
#   244 = Error retrieving configuration
#   253 = Unexpected output
#


### Main ###
if( $#ARGV != 4 && $#ARGV != 5 )
{
    print "Usage: specssh.pl <device IP> <user> <pass> <enable_pass> <login_timeout_in_seconds> <capture_timeout_in_seconds>\n";
    print STDERR "Usage:  specssh.pl <deviceIP> <user> <pass> <enable_pass> <login_timeout_in_seconds> <capture_timeout_in_seconds>\n";
    exit 255;
}
elsif( $ARGV[4] < 1 || $ARGV[4] > 600 )
{
    print "$ARGV[4] is the login timeout and must be an int between 1 and 600 seconds\n";
    print STDERR "$ARGV[4] is the login timeout and must be an int between 1 and 600 seconds\n";
    exit 254;
}
elsif( $#ARGV == 5 && ( $ARGV[5] < 1 || $ARGV[5] > 600 ) )
{
    print "$ARGV[5] is the capture timeout and must be an int between 1 and 600 seconds\n";
    print STDERR "$ARGV[5] is the capture timeout and must be an int between 1 and 600 seconds\n";
    exit 254;
}
else
{


    my $capture_timeout = $ARGV[4];
    if( $ARGV[5] )
    {
       $capture_timeout = $ARGV[5];
    }

    $errorCode = 1;
    my $errorString = "\nHost $ARGV[0]:  \n";

    ($errorCode,@data) = GetConfig( $ARGV[0], $ARGV[1], $ARGV[2], $ARGV[3], $ARGV[4], $ARGV[5] );


    if( $errorCode == 0 )
    {
        # Success.  The startup configuration
        # content is in the data variable
        my $line;


        foreach $line (@data) {

		# Match any lines here that you don't want to show up in the configuration
		
                if (($line =~ m/sh run/) || ($line =~ m/Building configuration/) || ($line =~ m/Current configuration/) || ($line =~ m/\#$/)) {

                } else {

                        print("$line");
                }
        }
        print("\n");
        exit 0;
    }
    else
    {
        print STDERR $errorString;

        if( $errorCode == 253 )
        {
            print STDERR join " ", @data, "\nEnable password may be invalid\n";
        }
        else
        {
                print("Error\n");
        }

        exit $errorCode;
    }
}

exit 0;


sub GetConfig {

    $deviceIP=shift;
    my $user=shift;
    my $pass=shift;
    my $epass=shift;
    my $login_timeout=shift;
    my $capture_timeout=shift;
    my @config;
    my $msg;


	# path to the expect script
	
	@data = `$expscript $user $pass $deviceIP $capture_timeout`;


	my $size = @data;

	if ($size < 10) {

	$msg = "No data retrieved, the capture timeout may be too low.";
        	return( 244, $msg );

	} else {
        	$errorCode = 0;
        	return ($errorCode, @data);

	}



}